@@ -30,6 +30,77 @@ class CodeQLAnalysisUseCase:
         self._codeql_runner: Optional[CodeQLRunner] = None
 
     def execute(self, request: CodeQLAnalysisRequest) -> RepositoryAnalysisSummary:
+        """
+        Execute CodeQL analysis on a repo or monorepo
+        """
+        try:
+            if request.monorepo:
+                self._logger.info(
+                    f"Starting monorepo CodeQL analysis for: "
+                    f"{request.repository_path}"
+                )
+                return self._execute_monorepo_analysis(request)
+            else:
+                self._logger.info(
+                    f"Starting single repository CodeQL analysis for: "
+                    f"{request.repository_path}"
+                )
+                return self._execute_single_repo_analysis(request)
+
+        except Exception as e:
+            self._logger.error(f"CodeQL analysis failed: {e}")
+            raise
+
+    def _execute_monorepo_analysis(
+        self, request: CodeQLAnalysisRequest
+    ) -> RepositoryAnalysisSummary:
+        """
+        Execute CodeQL analysis on a monorepo by analyzing each project.
+        """
+        self._logger.info("Starting monorepo analysis...")
+
+        # Find all 1st-level folders inside the monorepo path
+        sub_project_paths = [p for p in request.repository_path.iterdir() if p.is_dir()]
+
+        if not sub_project_paths:
+            self._logger.warning("No projects found in the monorepo path.")
+            return RepositoryAnalysisSummary(
+                repository_path=request.repository_path,
+                detected_projects=[],
+                analysis_results=[],
+            )
+
+        all_detected_projects = []
+        all_analysis_results = []
+
+        for sub_path in sub_project_paths:
+            self._logger.info(f"Processing project: {sub_path}")
+
+            # Create a new request object for the project
+            sub_request = CodeQLAnalysisRequest(
+                repository_path=sub_path,
+                force_install=request.force_install,
+                target_languages=request.target_languages,
+                verbose=request.verbose,
+                output_directory=request.output_directory,
+            )
+
+            try:
+                summary = self._execute_single_repo_analysis(sub_request)
+                all_detected_projects.extend(summary.detected_projects)
+                all_analysis_results.extend(summary.analysis_results)
+            except Exception as e:
+                self._logger.error(f"Analysis failed for {sub_path}: {e}")
+
+        return RepositoryAnalysisSummary(
+            repository_path=request.repository_path,
+            detected_projects=all_detected_projects,
+            analysis_results=all_analysis_results,
+        )
+
+    def _execute_single_repo_analysis(
+        self, request: CodeQLAnalysisRequest
+    ) -> RepositoryAnalysisSummary:
         """
         Execute CodeQL analysis on a repository.
 
@@ -270,31 +341,12 @@ class CodeQLAnalysisUseCase:
             for language in project.languages:
                 self._logger.debug(f"Running CodeQL analysis for {language.value}")
 
-                # Create database
-                db_path = output_dir / f"db-{language.value}"
+                # Create database and run analysis using the robust method
                 if self._codeql_runner is None:
                     raise Exception("CodeQL runner not initialized")
 
-                db_result = self._codeql_runner.create_database(
-                    database_path=str(db_path),
-                    source_root=str(project.path),
-                    language=language.value,
-                    overwrite=True,
-                )
-
-                if not db_result.success:
-                    error_msg = (
-                        f"Failed to create database for {language.value}: "
-                        f"{db_result.stderr}"
-                    )
-                    self._logger.error(error_msg)
-                    result.status = AnalysisStatus.FAILED
-                    result.error_message = error_msg
-                    result.end_time = datetime.now()
-                    return result
-
-                # Run analysis
-                output_format = "sarif-latest"  # Default output format
+                # Default output format
+                output_format = "sarif-latest"
 
                 # Map output formats to conventional file extensions
                 format_to_extension = {
@@ -309,15 +361,20 @@ class CodeQLAnalysisUseCase:
 
                 file_extension = format_to_extension.get(output_format, ".sarif")
                 output_file = output_dir / f"results-{language.value}{file_extension}"
-                analysis_result = self._codeql_runner.analyze_database(
-                    database_path=str(db_path),
-                    output_format=output_format,
-                    output=str(output_file),
+
+                # Use the robust create_and_analyze method that handles corrupted databases
+                analysis_result = self._codeql_runner.create_and_analyze(
+                    source_root=str(project.path),
+                    language=language.value,
+                    output_file=str(output_file),
+                    database_name=str(output_dir / f"db-{language.value}"),
+                    cleanup_database=False,  # Keep database for debugging
                 )
 
                 if not analysis_result.success:
                     error_msg = (
-                        f"Failed to analyze {language.value}: {analysis_result.stderr}"
+                        f"Failed to create database and analyze {language.value}: "
+                        f"{analysis_result.stderr}"
                     )
                     self._logger.error(error_msg)
                     result.status = AnalysisStatus.FAILED
